# theama

The mandate of **theama** is, above all else, two things:

- Be a simple wrapper around opencv and scikit-image, including only the most
important algorithms and simple interfaces to interact with them.
- Provide Python-native implementations of CV algorithms that aren't in any
common Python library (such as VLAD, Fisher vectors, BoW, etc.).

## Installation

To install, simply run the following command:
```bash
pip install theama
```